#!/bin/bash
#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2012 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

# example for add one address
#./addremoveulaip.sh "eth1" "2002:97d:eec3:604:9:181:137:116/64" "add"

# example for remove one address
#./addremoveulaip.sh "eth1" "2002:97d:eec3:604:9:181:137:116/64" "remove"
#Log file path and name
ADD_REMOVE_IP_LOG="/var/log/fsm_addremoveip"
OP_ADD="add"
OP_REMOVE="remove"

add_or_remove_one_address(){
	#Make sure we have all required input parameters passed
	if [ $# -ne 3 ]; then
		echo "Usage: addremoveulaip.sh {nic_interface} {ip6_to_add_remove} {$OP_ADD|$OP_REMOVE}" >> $ADD_REMOVE_IP_LOG 2>&1
		exit 1
	fi
	
	local interface=$1
	local networkCfgFileName="ifcfg-$interface"
	local networkCfgFile="/etc/sysconfig/network/$networkCfgFileName"
	local networkCfgFileBakup="/tmp/${networkCfgFileName}.bak"
	
	# The address format is address/prefix length, like 2002:97d:eec3:604:9:181:137:129/64
	local address=`echo $2 | sed -e "s/::/:0:/g"`
	local operation=$3
   
   #make sure we have network configuration for given interface and is backed up
   if [ ! -e $networkCfgFile ]; then
		echo "Unable to find current network configuration file $networkCfgFile" >> $ADD_REMOVE_IP_LOG 2>&1
		exit 1
	else
		echo "Backup current configuration file at $networkCfgFileBakup" >> $ADD_REMOVE_IP_LOG 2>&1
		cp -f $networkCfgFile $networkCfgFileBakup
   fi
     
   #do requested operation
   case "$operation" in
	   $OP_ADD)
	   		command="/opt/ibm/director/vmi/scripts/execWithPrivilege/networkUtil -c interface -s add -i $interface -a $address"
			echo "Adding ip address $address to interface $interface using command $command" >> $ADD_REMOVE_IP_LOG 2>&1
			$command
			;;			
		$OP_REMOVE)
			command="/opt/ibm/director/vmi/scripts/execWithPrivilege/networkUtil -c interface -s remove -i $interface -a $address"			
			echo "Removing ip address $address from interface $interface using command $command" >> $ADD_REMOVE_IP_LOG 2>&1
			$command
			;;			
		*)
			echo "Invalid operation passed." >> $ADD_REMOVE_IP_LOG 2>&1
			echo "Usage: addremoveulaip.sh {nic_interface} {ip6_to_add_remove} {$OP_ADD|$OP_REMOVE}" >> $ADD_REMOVE_IP_LOG 2>&1
			exit 1
			;;
   esac
   
   exit 0
}

########################################
#   Main entry
########################################
echo ""
echo ""
echo "########### `date +"%Y%m%d%H%M%S"` #############" >> $ADD_REMOVE_IP_LOG 2>&1
add_or_remove_one_address $1 $2 $3
exit $?