#! /bin/sh 
#
# Licensed Materials - Property of IBM
# OCO Source Materials
# 
# (C) Copyright IBM Corp. 2011 All Rights Reserved
# The source code for this program is not published or otherwise divested of its 
# trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
#

# this is a plugin script invoked by the chconfig command. Its purpose is to check
# if the -l argument(locale) was specified to chconfig and, if so, then check if the FSM
# is at a level that supports translation.  If the FSM does not support translation
# then the option to change the system locale will be blocked, exit with a non zero return code.



#check if parameter is -l for locale
function collectParameters ()
{
    case $3 in
     --datetime)    exit 0
                    ;;
     --help)        exit 0
                    ;;
     --clock)       exit 0
                    ;;
     --timezone)    exit 0
                    ;;
     --regensshkey) exit 0
                    ;;
     --nonstop)     exit 0
                    ;;
     --resolution)  exit 0
                    ;;
     -l)            ;;
    esac
}

if [ "$#" -lt "1" ]; then  
   exit 0
else
   collectParameters $@
   
   #read the current FSM version
   FSMversion=`sed '/^\#/d' "/opt/ibm/director/vmi/data/overwrite/fsm_native.version" | grep 'version'  | tail -n 1 | cut -d "=" -f2- | cut -c 1`
   #echo $FSMversion

   if [ $FSMversion -lt 2 ]; then
       echo "-l argument not supported with current IBM Flex System Manager version." 
       exit 1
   else
       exit 0
   fi

fi

