// dojo.provide allows pages to use all of the types declared in this resource.

define(["ibm/tivoli/tip/TCTTable", "dojo/_base/kernel", "dojo/_base/declare", "dijit/_WidgetBase", 
		"dijit/layout/BorderContainer",
		"dijit/layout/ContentPane",
		"fsm/DataStore",
		"fsm/CommonActions",
		"fsm/ChassisMapLaunchHack",
		"fsm/chassisMap",
		"ibm/tivoli/tip/navwidget/dijit/DefaultMessageHandler",
		"framework/OneUIItemsTableView",
		"ibm/tivoli/tip/navwidget/properties/dijit/PropertiesNotebook",
		"navwidget/topology/dijit/DefaultMenuProviderHelper",
		"dojo/data/ItemFileReadStore",
		"ibm/tivoli/tip/navwidget/dijit/RESTContextMenuProvider",
		"ibm/tivoli/navmodel/Dataset",
		"util/DefaultDialogTask",
		"activealerts/DemoActiveAlertsDataset",
		"dojo/topic",
		"dojo/_base/xhr", "dojo/_base/connect", "dojo/_base/lang", "dijit/registry"],
	function (TCTTable, dojo, declare, WidgetBase, BorderContainer, ContentPane, DataStore, CommonActions, ResourceNavigatorDAHelper, ChassisMap, 
	DefaultMessageHandler, ItemsTableView, PropertiesView, DefaultMenuProviderHelper, ItemFileReadStore, RESTContextMenuProvider, 
	Dataset, DefaultDialogTask, DemoActiveAlertsDataset, topic) {

	return declare([WidgetBase, BorderContainer], {

    gutters : false,
    design : "headline",
    liveSplitters : true,
    /* sections of layout */
    actionsBar : null,
    statusBar : null,
    mainPane : null,
    selection: null,
    _dataStore: null,
    _commonActions: null,
    _chassisListTable: null,
    _actionHelper: null,
    _cmProvider: null,
   
    postCreate : function() {
        this.inherited(arguments);
        this.createContainers();    
        topic.publish("updateTitle", {view: "Managed Chassis"});
        // create a default context menu provider
			var helper = new DefaultMenuProviderHelper();			
			this._cmProvider = new RESTContextMenuProvider({
					view : this,
					getMenuItemsCallback : dojo.hitch(helper, helper.getMenuItems),
					getMenuCommandCallback : dojo.hitch(helper, helper.getMenuCommand)
				});
		//var defaultActionHelper = new ResourceNavigatorDAHelper({defaultActionCallback: dojo.hitch(this, "_launchChassisMap", this)});
		this._actionHelper = new ResourceNavigatorDAHelper({parent:this});
    	this._createChassisList();
    	var div = this.createElement(this.actionsBar.domNode, 'actionsMenuDiv', {
        	elementType: 'div', styleClass: 'actionsBoxContainer'
        	});
        this._commonActions = new CommonActions({}, div);   
		//				
		
    },
    _createChassisList : function() {
        this._chassisListTable = new ItemsTableView({
					id : "chassisListTable",
					daHelper: this._actionHelper,
					cmProvider : this._cmProvider
				}, this.createElement(this.mainPane.domNode, 'chassisListTableContainer', {elementType: 'div'}));
		this._chassisListTable.startup();
		//Register for selection changes
		dojo.connect(this._chassisListTable.selection, "onSelectionChanged", dojo.hitch(this, this.selectionHasChanged));
		
		this._dataStore = new DataStore({
                datasetId : 'ALL_CHASSIS',
                homeParms : null,
                getItems : true,
                retrieveItemProperties : true,
                getTasks : true,
                initReadyCallback : dojo.hitch(this, this.initializeDataStores)
            });        
              
        
        //hack, resize after table and actions are retrieved from server. Figure out better way.
        window.setTimeout(dojo.hitch(this, this.resize), '5000');
    },
    initializeDataStores : function() {
    	this._chassisListTable.setDataset(this._dataStore.getDataset());
    },
    createElement : function(parentNode, elementId, parms) {
        var newElement;
        if (!parms)
            parms = {};
        var elementType = (parms.elementType) ? parms.elementType : "div";

        if (dojo.byId(elementId))
            return dojo.byId(elementId);

        try {
            newElement = document.createElement(elementType);

            dojo.attr(newElement, "id", elementId);
            if (parms.styleClass)
                dojo.attr(newElement, "class", parms.styleClass);
            if (parms.style)
                dojo.attr(newElement, "style", parms.style);

            // IE hack, we have to clone the node and do future work from the clone
            if (parentNode)
                parentNode.appendChild(newElement.cloneNode(true));
            else
                newElement.cloneNode(true);
            newElement = dojo.byId(elementId);
        } catch (e) {
        }

        if (parms.baseDimensionsOnNode && newElement) {
            var sizeToElementCBox = dojo.contentBox(parms.baseDimensionsOnNode);
            dojo.contentBox(newElement, {
                w : sizeToElementCBox.w,
                h : sizeToElementCBox.h
            });
        }
        if (parms.innerHTML)
            newElement.innerHTML = parms.innerHTML;

        return newElement;
    },
    createContainers : function() {
        this.createActionsBar();
        this.createStatusBar();
        this.createMainPane();
    },
    //selection changed callback
	selectionHasChanged : function (selection) {
		console.log("SELECTION!! selection = " + selection.getItemIds());
		if(this.selection) {
			if(this.selection === selection.getItemIds()) {
				return;
			} else {
				console.log("SELECTION CHANGED!! selection = " + selection.getItemIds() + " and previous " + this.selection);				
				this._commonActions.selectionChanged(selection.getItemIds());
			}
			if(selection.getItemIds().length > 0 && selection.getItemIds().indexOf(',') === -1) {
				//this._createPropertiesView(selection.getItemIds());
			} else {
				//this._destroyPropertiesView();
			}			
		} 
		this.selection = selection.getItemIds();
	},
	_createPropertiesView : function(selectedItem) {
		 this._propertiesView = new PropertiesView({
					id : "chassisProperties"
				}, this.createElement(this.statusBar.domNode, 'propertiesViewContainer', {elementType: 'div'}));
		this._propertiesView.startup();
		//Register for selection changes
		
		var propertiesDatastore = new DataStore({
                datasetId : 'ALL_CHASSIS',
                homeParms : null,
                getItems : true,
                retrieveItemProperties : true,
                getTasks : true,
                initReadyCallback : dojo.hitch(this, this.initializeDataStores)
            });        
	},
	_destroyPropertiesView : function() {
	
	},
	launchChassisMap: function(selectedChassis) {
		console.info('launchCHassisMap');		
		this._chassisListTable.destroyRecursive();
		//bug in widget:
		if (dijit.byId('chassisListTable_itemContentDiv_tooltipProperties')) {
			dijit.byId('chassisListTable_itemContentDiv_tooltipProperties').destroyRecursive();
		}
		var chassisMap = new ChassisMap({oid: selectedChassis, goback: dojo.hitch(this, this.goBackToChassisList)}, this.createElement(this.mainPane.domNode, 'chassisListTableContainer', {elementType: 'div'}));
	},
	goBackToChassisList: function() {
		console.info('goback');		
		this._chassisListTable.destroyRecursive();
		this._createChassisList();
	
	},
    createActionsBar : function() {
        this.actionsBar = this.createSection('actionsBar', 'actionsBarPane', 'right', 'true');
    },
    createStatusBar : function() {
        this.statusBar = this.createSection('statusBar', 'statusBarPane', 'bottom', 'true');
    },
    createMainPane : function() {
        this.mainPane = this.createSection('mainPane', 'mainPane', 'center', 'true');
    },    
    createSection : function(sectionId, className, region, splitters) {
        dojo.create('div', {
            id : sectionId
        }, this.domNode);
        var pane = new ContentPane({
            splitters : splitters,
            region : region
        }, sectionId);
        pane.attr("class", className);
        return pane;
    }
});
});