define(["dojo/_base/declare","dojo/i18n",
		"fsm/DataStore"],
	function (declare, i18n, DataStore) {

	return declare([], {
	
	_parentDomNodeId: null,
	_selection:null,
	
	_dataStore: null,
	MRI: {CommonActions: 'Common Actions'},
	
	constructor: function(args){ 
		dojo.mixin(this, args);
		this._createCommonActionsList();
	},
	
	_doClick: function(taskId, nonInteractive) {		
		var selectedTaskId = taskId;	
		if(nonInteractive === 'true') {
			alert('taskId ' + taskId + ' is a non-interactive task, not supported yet');
			return;
		}	
		var selectionStr = (this._selection + '');
		if(selectionStr.indexOf(',') != -1) {
			selectionStr = selectionStr.split(',');
		}
		launchInContext(selectedTaskId, selectionStr.split(','));
	},
	
	_createCommonActionsList: function() {
		 this._dataStore = new DataStore({
                datasetId : 'COMMON_ACTIONS_COLLECTION',
                homeParms : this._selection,
                sourceToken : this._selection,
                getItems : true,
                retrieveItemProperties : true,
                getTasks : false,
                initReadyCallback : dojo.hitch(this, this._createTheCommonActionsList)
            });
	},
	createElement : function(parentNode, elementId, parms) {
        var newElement;
        if (!parms)
            parms = {};
        var elementType = (parms.elementType) ? parms.elementType : "div";

        if (dojo.byId(elementId))
            return dojo.byId(elementId);

        try {
            newElement = document.createElement(elementType);

            dojo.attr(newElement, "id", elementId);
            if (parms.styleClass)
                dojo.attr(newElement, "class", parms.styleClass);
            if (parms.style)
                dojo.attr(newElement, "style", parms.style);

            // IE hack, we have to clone the node and do future work from the clone
            if (parentNode)
                parentNode.appendChild(newElement.cloneNode(true));
            else
                newElement.cloneNode(true);
            newElement = dojo.byId(elementId);
        } catch (e) {
        }

        if (parms.baseDimensionsOnNode && newElement) {
            var sizeToElementCBox = dojo.contentBox(parms.baseDimensionsOnNode);
            dojo.contentBox(newElement, {
                w : sizeToElementCBox.w,
                h : sizeToElementCBox.h
            });
        }
        if (parms.innerHTML)
            newElement.innerHTML = parms.innerHTML;

        return newElement;
    },
	_createTheCommonActionsList: function() {	
    try {if ( this._dataStore ) {
      	var menuData = this._dataStore.getItems();	  
  		var divNode = dojo.byId(this._parentDomNodeId);
        var lastCategory = "";
        var j = 0;
        for (var i = 0; i < menuData.length; i++) {
          if (this._dataStore.getItemProperty(menuData[i], "COMMON_ACTION_TYPE") == "GENERAL_ACTION") {
          	  continue; 
          }
          if (j === 0) { //means we have at least one common action, create title
            this.createElement(divNode, 'commonActionsHeaderText', {styleClass: 'actionsHeadingText', innerHTML: this.MRI.CommonActions});
          }
          var category = this._dataStore.getItemProperty(menuData[i], "COMMON_ACTION_CATEGORY_NAME");  
          var nonInteractive = this._dataStore.getItemProperty(menuData[i], "COMMON_ACTION_NON_INTERACTIVE");  		          
  	      if(category.length == 0) {
  		  	category = "General";
  		  }
		  if (!(category == lastCategory)) {
            this.createElement(divNode, 'category' + category, {styleClass: 'actionsHeading', innerHTML: category});
          }
          j++;
  		  lastCategory = category;
  		  var itemLabel = this._dataStore.getItemProperty(menuData[i], "COMMON_ACTION_NAME");
  		  var itemId = this._dataStore.getItemProperty(menuData[i], "ACTION_ID");              
          var link = this.createElement(divNode, category + 'element' + itemId, {elementType: 'span', 
          					 innerHTML: itemLabel, styleClass: 'actionLink'});
          dojo.connect(link, 'onclick', dojo.hitch(this, this._doClick, itemId, nonInteractive));

  		  }
       }
    } catch (error) {
    	console.error(error);
    }
	},
	

});
});