// dojo.provide allows pages to use all of the types declared in this resource.

define(["dojo/_base/declare",
		"ibm/tivoli/navmodel/Dataset"
		],function (declare, Dataset) {
	return declare([], 
	{	

    constructor : function(args) {
        dojo.mixin(this, args);       
    },    
    /**
     * @param navModelId -
     *            (Required)String - Custom collection Id you wish to retrieve
     * @param requestCallBack -
     *            (Required)Function(args) - Callback function that will be called when the dataset is created,
     *            containing the dataset metadata(attributes) only, no Nodes. args.getAttribute(attributeKey) will
     *            return the metadata attribute for that key.
     * @param homeParms -
     *            String - Home parms to be sent to the collection.
     * @param nodesRetrievedCallBack -
     *            Function(args) - Callback function that will be called with the list of nodes (items) of the
     *            collection you retrieved. args will be an array of items, or an empty array if no items present.
     * @param errorCallBack -
     *            Function(args) - callback function that will be called if any errors occur.
     */
    sendCuriDataRequest : function(navModelId, requestCallBack, requestErrorCallBack, homeParms,
        nodesRetrievedCallBack, errorCallBack, retrieveItemProperties) {
        var myParameters = {};
        if (homeParms) {
            myParameters.homeParms = homeParms;
        }
        this._sendDataRequest(myParameters, "/ibm/tivoli/rest", navModelId, requestCallBack, requestErrorCallBack,
            nodesRetrievedCallBack, errorCallBack, retrieveItemProperties);

    },
    _sendDataRequest : function(myParameters, myBaseUrl, myDataset, requestCallBack, requestErrorCallBack,
        nodesRetrievedCallBack, errorCallBack, retrieveItemProperties) {

        var dataset = new Dataset({
            baseUrl : myBaseUrl,
            provider : "USMI",
            datasource : "",
            dataset : myDataset,
            parameters : myParameters,
            useDatastore : false,
            onComplete : requestCallBack,
            onError : requestErrorCallBack,
            defaultProperties : [ "all" ]
        });
        if (requestCallBack) {
            dataset.onComplete = requestCallBack;
        }
        if (requestErrorCallBack) {
            dataset.onError = requestErrorCallBack;
        }
        if (retrieveItemProperties) {
            dataset.defaultProperties = [ "all" ];
        }
        if (nodesRetrievedCallBack) {
            var functions = {
                onComplete : nodesRetrievedCallBack
            };
            if (errorCallBack) {
                functions.onError = errorCallBack;
            }
            dataset.getItemsAndLinks(functions);
        }

        //dataset.getTasks(functions);

    }

});
});