// dojo.provide allows pages to use all of the types declared in this resource.

define(["dojo/_base/declare", "fsm/ConsoleDataEngine" 
		],function (declare, DataEngine) {
	return declare([], 
	{	
    _dataset : null,
    _items : null,
    _tasks : null,
    _dataEngine : null,
    _eventCountToNotify : 1, //default is 1, since we always get the dataset event
    _currentEventCount : 0,
    constructorParms : null,
    /* constructorParms:
    getItems
    getTasks
    retrieveItemProperties
    datasetId
    homeParms
    itemIds
    initReadyCallback    
    */
      
    constructor : function(args) {
    	this.constructorParms = {};
        dojo.mixin(this.constructorParms, args);
        this._dataEngine = new DataEngine();
        this._setupEventListening();
        if (this.constructorParms.getItems === true) {
            if (this.constructorParms.retrieveItemProperties === true) {
                this._dataEngine.sendCuriDataRequest(this.constructorParms.datasetId, dojo.hitch(this,
                    this._datasetRetrieved), dojo.hitch(this, this._errorOnDatasetRetrieved),
                    this.constructorParms.homeParms, dojo.hitch(this, this._datasetItemsRetrieved), dojo.hitch(this,
                        this._errorOnDatasetItemsRetrieved), true);
            } else {
                this._dataEngine.sendCuriDataRequest(this.constructorParms.datasetId, dojo.hitch(this,
                    this._datasetRetrieved), dojo.hitch(this, this._errorOnDatasetRetrieved),
                    this.constructorParms.homeParms, dojo.hitch(this, this._datasetItemsRetrieved), dojo.hitch(this,
                        this._errorOnDatasetItemsRetrieved));
            }
        } else {
            this._dataEngine.sendCuriDataRequest(this.constructorParms.datasetId, dojo.hitch(this,
                this._datasetRetrieved), dojo.hitch(this, this._errorOnDatasetRetrieved),
                this.constructorParms.homeParms);
        }

    },
    getDataset : function() {
    	return this._dataset;
    },
    getTasks : function() {
        return this._tasks;
    },
    getItems : function() {
        return this._items;
    },
    getDatasetAttribute : function(key) {
        return this._dataset.getAttribute(key);
    },
    getTasks : function() {
        return this._tasks;
    },
    getItem : function(index) {
        return this._items[index];
    },
    getItemProperty : function(item, property) {
        return item.getProperty(property).getValue();
    },
    getItemProperties : function(item) {
        var properties = {};
        var itemProps = item.getCachedPropertyIds(true);
        var i = 0;
        for (i = 0; i < itemProps.length; i++) {
            properties[itemProps[i]] = item.getProperty(itemProps[i]).getValue();
        }
        return properties;
    },
    executeTask : function(task, args) {
        var taskArgs = {
            onComplete : function(result, kwArgs) {
               // Utils.Trace('task', 'success');
            },
            onError : function(error, exception, ioArgs) {
              //  Utils.Trace('task', 'error');
            },
            selectionParms : {}
        };
        dojo.mixin(taskArgs, args);
        if (typeof task === "string") {
            var i;
            for (i = 0; i < this._tasks.length; i++) {
                if (this._tasks[i].getId() == task) {
                    task = this._tasks[i];
                }
            }
        }
        taskArgs.selection = new ibm.tivoli.navmodel.Selection({
            version : '1'
        });

        task.execute(taskArgs);
    },
    _setupEventListening : function() {
        this._eventCountToNotify = 1;
        this._currentEventCount = 0;
        if (this.constructorParms.getItems === true) {
            this._eventCountToNotify++;
        }
        if (this.constructorParms.getTasks === true) {
            this._eventCountToNotify++;
        }

    },
    _datasetRetrieved : function(dataset) {
      //  Utils.Trace('_datasetRetrieved');
      //  Utils.Trace(dataset);
        this._dataset = dataset;
        if (this.constructorParms.getTasks) {
            var functions = {
                onComplete : dojo.hitch(this, this._datasetTasksRetrieved),
                onError : dojo.hitch(this, this._errorOnDatasetTasksRetrieved)
            };
            this._dataset.getTasks(functions);
        }
        this._eventReceived();
    },
    _errorOnDatasetRetrieved : function(error) {
        //TODO: allow callback on exploiters to get notified of specific errors
        this._retrievalError(error);
    },
    _datasetItemsRetrieved : function(items) {
       console.info('_datasetItemsRetrieved' + this.constructorParms.datasetId);
        this._items = items;
        this._eventReceived();
    },
    _errorOnDatasetItemsRetrieved : function(error) {
        //TODO: allow callback on exploiters to get notified of specific errors
        this._retrievalError(error);
    },
    _datasetTasksRetrieved : function(tasks) {
       console.info('_datasetTasksRetrieved');
       // Utils.Trace(tasks);

        this._tasks = tasks;
        this._eventReceived();
    },
    _errorOnDatasetTasksRetrieved : function(error) {
        //TODO: allow callback on exploiters to get notified of specific errors
        this._retrievalError(error);
    },
    _retrievalError : function(error) {
       console.error('Dataset error for ' + this.datasetId);
       console.error(error);
    },
    _eventReceived : function() {
        if (this.constructorParms.initReadyCallback == null) {
            return;
        }
        this._currentEventCount++;
        if (this._currentEventCount === this._eventCountToNotify) {
            this.constructorParms.initReadyCallback();
        }
    }

});
});