#!/bin/sh
#####################################################################################
#
# FSM-Plugin Update Install Script
#  
#####################################################################################
################################################################################################
################################################################################################
# This script is run when the FSM GUI Plugins are installed on an FSM as part of a FSM update.  The
# FSM GUI Plugins are installed like a Director plugin, as a Eclipse/Feature Update.  An Eclipse/
# Feature Update version of the plugins is built any time new code is checked in and a continuous
# build is kicked off.  The next build of the FSM fix package will pick up the latest version
# of the plugins to include in the overall FSM fix package.
# The plugins will be installed by the Eclipse/Feature update processing, but there can be additional
# processing that is required to support the update of the plugins.  Eclipse/Feature processing
# allows for "non-plugin data" to be included in the update package and allows for a install handler
# to be created to act on the non-plugin data or to perform other functions.  This script is the
# installhandler script that has defined for the FSM GUI Plugins.  Script code can be placed in this script,
# checked in, and delivered and it will be picked up in the next continuous build.
###############################################################################################
# Global script variables
# Log to /opt/ibm/director/lwi/logs/fsmUpdateLog_yymmdd.log
TODAY=`date '+%y%m%d'`
# Collected by pedbg.  Do not change this unless you change fsmCopyLogs script
# in com.ibm.itme.build/appliance/pedbg
LOGFILE=/opt/ibm/director/lwi/logs/fsmUpdateLog_${TODAY}.log
DATETIME=`date`   
#
###############################################################################################
#
#
# In this script, the following logging is turned on 
#  1) Logging of every command to stdout (set -x)
#  2) Sending stdout and stderr to $LOGFILE (exec > >(tee -a $LOGFILE) 2>&1)
#
#  # Ignore for now.  SCript does no end on error unless script code below
#  #   exits.  
#  #If you need to check $? in your script to take a special action, call
#  #turn_off_error_chk().  As soon a the check is complete turn back on error
#  #checking/reporting by calling turn_on_error_chk()
#
#  The following script commands set this up.  These should not be deleted.
###############################################################################################
#
# Place stdout and stderr in LOGFILE and to console
exec >> $LOGFILE 2>&1

# Send each command in script to STDOUT
set -x

# This routine is called if a command has an error in the script.
handle_error() {
    
    echo "$(basename $0)  caught error on line : $1 command was: \"$2\" : Error was " $3
    #exit $3
}

# Turn on command error reporting
turn_on_error_chk() {
  trap 'handle_error $LINENO "$BASH_COMMAND" $?' ERR
}

# Turn off command error checking
turn_off_error_chk() {
  trap " " ERR
} 

# Turn on automatic error catching
# Any command that ends in an error will be caught and the script will end and report the error
turn_on_error_chk

##############################################################################################
# Utility Functions
##############################################################################################
checkInstall() {
rc=$1
if [[ $rc = 1 ]]; then
	   #File may already be installed, error code 1 comes back if installed.  Need to handle....
	   LOG "checkInstall():rpm already installed - this is OK..."
else
	LOG "checkInstall() : if not '1', do normal error checking.. rc = $rc... (? = $?)..."
	checkRC $rc
fi
}

checkRC() {
rc=$1
LOG "checkRC():RC is $rc"
	if [[ $rc != "0" ]]; then
	   LOG "checkRC() : error - ending installupdate... rc = $rc..."
	   exit $rc
	fi
}
#############################################################################################

#============================================================================
# Upgrade LDAP server function.  Will check the current level of the 
# LDAP server and upgrade if required. 
# ===========================================================================
upgrade_ldap() {
  # START: Upgrade LDAP
  echo "***START: LDAP upgrade***"
  DIRECTOR_ROOT=/opt/ibm/director
  FRM_LIB=$DIRECTOR_ROOT/lwi/runtime/itme/eclipse/plugins
  JAVA_EXE=/opt/ibm/java-i386-60/jre/bin/java
  UPGRADE_PGM=com.ibm.itme.usermgmt.config.LdapUpgrade

  # NOTE: the remoteaccess jars are signed and contain the CommandRunner class in a sub-jar that causes
  #       a SecurityException in the class loader (conflicts with utils.jar) so we can't have it in the classpath
  # Set the CLASSPATH to include all itme jars
  #for f in $( find "$FRM_LIB" -name "*.jar" ); do
  #  TOOL_CLASSPATH=$TOOL_CLASSPATH$f:
  #done

  TOOL_CLASSPATH=/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.utils_${utilsVersion}/classes/utils.jar
  TOOL_CLASSPATH=$TOOL_CLASSPATH:/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.usermgmt_${usermgmtVersion}/classes/com.ibm.itme.usermgmt.jar
  TOOL_CLASSPATH=$TOOL_CLASSPATH:/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.common_${commonVersion}/classes/common.jar
  TOOL_CLASSPATH=$TOOL_CLASSPATH:/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.tasks_${tasksVersion}/classes/tasks.jar
  TOOL_CLASSPATH=$TOOL_CLASSPATH:/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.utils_${utilsVersion}/aspectjrt.jar:
  LWI_PASSWORD_UTIL_JAR=/opt/ibm/director/lwi/lib/passutils.jar
  CORE_KERNEL_JAR=$(find "/opt/ibm/director/lwi/runtime/USMiMain/eclipse/plugins" -name core-kernel.jar | tail -n 1)
  OSGI_JAR=$(find "/opt/ibm/director/lwi/runtime/core/eclipse/plugins" -name org.eclipse.osgi_*.jar | tail -n 1)
  WEBAPP_JAR=$(find "/opt/ibm/director/lwi/runtime/core/eclipse/plugins" -name org.osgi.service.webapplication_*.jar | tail -n 1)
  MESSAGE_UTIL_JAR=$(find "/opt/ibm/director/lwi/runtime/USMiResource/eclipse/plugins" -name com.ibm.director.core.common_*.jar | tail -n 1)
  ICUTEXT_JAR=$(find "/opt/ibm/director/lwi/runtime/core/eclipse/plugins" -name com.ibm.icu_*.jar | tail -n 1)
  TOOL_CLASSPATH=$TOOL_CLASSPATH$CORE_KERNEL_JAR:$MESSAGE_UTIL_JAR:$LWI_PASSWORD_UTIL_JAR:$OSGI_JAR:$WEBAPP_JAR:$ICUTEXT_JAR:

  # Need to set the path for the jre/jvm
  export PATH=/usr/lib64/jvm/java-1.5.0-ibm/bin:$PATH

  # The environment is setup up.  Call the java program 
  echo " " 
  echo "***** START $UPGRADE_PGM OUTPUT *****" 
  # Commented out lines (### or ##) in this function are replaced by installFSMUpdateLdap.sh to handle HA,
  # parm 0 = stop ldap, parm 1 = start ldap
  # If tests are successful, these lines can be removed.
  echo " " 
  ###/usr/smrshbin/disableLdapWatchdog
  rm -rf /tmp/ldapConfigV1.ldif
  slapcat -n 0 -l /tmp/ldapConfigV1.ldif
  echo "#!/bin/sh" > /tmp/ldapClean.sh
  echo "rm -rf /etc/openldap/slapd.d/*" >> /tmp/ldapClean.sh
  chmod 700 /tmp/ldapClean.sh
  ##/etc/init.d/ldap start
  $pluginsDir/bin/installFSMUpdateLdap.sh 1
  $JAVA_EXE -cp $TOOL_CLASSPATH $UPGRADE_PGM  
  $pluginsDir/bin/installFSMUpdateLdap.sh 0
  ## /etc/init.d/ldap stop
  rm -rf /tmp/ldapClean.sh
  /usr/sbin/slapindex -n 1
  $pluginsDir/bin/installFSMUpdateLdap.sh 1
  ##/etc/init.d/ldap start
  ### /usr/smrshbin/enableLdapWatchdog
  RET=$? 
  echo " " 
  echo "Return Code: $RET" 
  echo " " 
  echo "***** END $UPGRADE_PGM OUTPUT *****" 
  echo " " 

  # Check for failure
  if [ $RET -ne 0 ]; then
    echo "LDAP upgrade failed." 
    ##/etc/init.d/ldap stop
    $pluginsDir/bin/installFSMUpdateLdap.sh 0
    slapadd -F /etc/openldap/slapd.d -n 0 -l /tmp/ldapConfigV1.ldif
    $pluginsDir/bin/installFSMUpdateLdap.sh 1
   ## /etc/init.d/ldap start
    exit 1
  fi
  
  echo "***END: LDAP upgrade***" 
  # END: Upgrade LDAP
}

#============================================================================
# End - Upgrade LDAP server function.  Will check the current level of the 
# LDAP server and upgrade if required. 
# ===========================================================================


# Put first entry into log file with eye catcher to indicate script has started to run ...
echo " "
echo ">>>>> Running installFSMUpdate.sh on ${DATETIME} <<<<<" 
echo " "
 
#Terminate script if a command fails,  set +e will trun this off if
#error checking is needed in the script below
# set -e    
# A debugging mode which prints each line of the script



# Establish variables for later use
echo "***** Establish variables for later use *****" 
itmeDir=/opt/ibm/director/lwi/runtime/itme
pluginsDir=$itmeDir/eclipse/plugins
directorItmeDir=/opt/ibm/director/itme
itmeproddataDir=/opt/ibm/director/proddata/itme
overridesdir=/opt/ibm/director/lwi/conf/overrides


# The build of the FSM GUI Plugins update package includes a properties and perftools directory in the
# non-plugin-data.zip file.  If you need to include a file in the non-plugin-data.zip file
# so that it can be deployed by a FSM GUI Plugin update package, notify the FSM update build team
# so the build can be updated to include the file.   
echo "***** Move the properties and perftools to itme dir. *****"
turn_off_error_chk
mkdir -p $itmeDir/properties
mkdir -p $itmeDir/perfTools
rm -r  $itmeDir/properties
rm -r  $itmeDir/perfTools
turn_on_error_chk

mv $itmeproddataDir/properties $itmeDir  
mv $itmeproddataDir/perfTools $itmeDir  
# make perftools executable
chmod 755 $itmeDir/perfTools/*.sh

# This will define several version properties for this script
# See FRM.version.properties in com.ibm.itme.build/properties for a list of properties that are defined
# The build of the FSM GUI Plugins update package includes FRM.version.properties file
chmod 755 $itmeDir/properties/FRM.version.properties
. $itmeDir/properties/FRM.version.properties

# create the linkable help messages in the plugins.
chmod 755 addMsgLinks2plugin.sh
./addMsgLinks2plugin.sh

# Copy files to support custom log collection for pedbg
echo "***** Move the ./pedbg to itme dir. *****"
turn_off_error_chk
mkdir -p $itmeDir/pedbg
rm -r  $itmeDir/pedbg
turn_on_error_chk

mv $itmeproddataDir/pedbg $itmeDir  

#  fsmCopyLogs ->  /opt/ibm/director/itme/fsmCopyLogs
#  fsmCopyLogs -> /opt/ibm/director/vmi/data/pedbg  (needed for -x option) 
#  fsm.pdcfg -> /opt/ibm/director/vmi/data/pedbg
#  fsm.xpddcfg -> /opt/ibm/director/vmi/data/pedbg 
echo " Copy custom pedbg script files..."
cp -f -P $itmeDir/pedbg/fsmCopyLogs $directorItmeDir  
cp -f -P $itmeDir/pedbg/fsmCopyLogs /opt/ibm/director/vmi/data/pedbg  
cp -f -P $itmeDir/pedbg/fsm.pdcfg /opt/ibm/director/vmi/data/pedbg  
cp -f -P $itmeDir/pedbg/fsm.xpdcfg /opt/ibm/director/vmi/data/pedbg  
#cp -f  -P $itmeDir/pedbg/fsmNetCheck.sh $directorItmeDir
#cp -f  -P $itmeDir/pedbg/fsmNetCheck.sh /opt/ibm/director/vmi/data/pedbg
chmod 755 $directorItmeDir/fsmCopyLogs  
chmod 755 /opt/ibm/director/vmi/data/pedbg/fsm.pdcfg  
chmod 755 /opt/ibm/director/vmi/data/pedbg/fsm.xpdcfg  
#chmod 755 $directorItmeDir/fsmNetCheck.sh
#chmod 755 /opt/ibm/director/vmi/data/pedbg/fsmNetCheck.sh
# Create symbolic links for DPSM scripts so they can run as root
ln -f -s /opt/hsc/bin/lssyscfg /opt/ibm/director/vmi/scripts/execWithPrivilege/lssyscfg
ln -f  /opt/hsc/sbin/copyLogs /opt/ibm/director/vmi/data/pedbg/copyLogs
# copy utils scripts to VMI script directory
echo "Copying ITME utils and datamgmt ldap scripts to vmi/upgrade ..."
chmod 755 $pluginsDir/com.ibm.itme.utils_${utilsVersion}/*.sh
chmod 755 $pluginsDir/com.ibm.itme.utils_${utilsVersion}/*.xml
chmod 755 $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/*.sh
chmod 755 $pluginsDir/com.ibm.itme.audit_${auditVersion}/*.sh
cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/05-save-ldap-config.sh /opt/ibm/director/vmi/upgrade/script
cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/05-upgrade-ldap-config.sh /opt/ibm/director/vmi/upgrade/deferred
# copy utils scripts to HA.
cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/fsmldapmonitor.sh /opt/ibm/director/ha/plugins/tsa
cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/fsmldapHAcfg.sh /opt/ibm/director/ha/plugins/tsa/m.2
#cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/fsmbackupschedulerHAcfg.sh /opt/ibm/director/ha/plugins/tsa
#cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/fsmbackupschedulermonitor.sh /opt/ibm/director/ha/plugins/tsa/m.2
cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/fsmbackupscheduleHAmonitor.sh /opt/ibm/director/ha/plugins/tsa/m.event
#cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/fsmbackupschedulermonitor.sh /opt/ibm/director/ha/plugins/tsa/m.2
cp -f  -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/conf_ldap.sh /opt/ibm/director/ha/plugins/conf

# create HA mirroring configuration for LDAP
if [ ! -f "/opt/ibm/vmi/data/disklayout.d/ldap_disklayout.cfg" ]; then
  cp -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion}/ldap_disklayout.cfg /opt/ibm/vmi/data/disklayout.d/
  chmod 644 /opt/ibm/vmi/data/disklayout.d/
  /usr/bin/dos2unix /opt/ibm/vmi/data/disklayout.d/ldap_disklayout.cfg
  turn_off_error_chk
  mkdir -p /mirror0/os/ldap/var/lib/ldap
  turn_on_error_chk
  
  cp -ra /var/lib/ldap/* /mirror0/os/ldap/var/lib/ldap
  turn_off_error_chk
  mkdir -p /mirror0/os/ldap/etc/openldap
  turn_on_error_chk
  
  cp -ra /etc/openldap/* /mirror0/os/ldap/etc/openldap

# update /etc/fstab
  /opt/ibm/vmi/bin/updatefstab -w
fi
# end create HA mirroring
# Create the new standby dir
echo "Creating new directories /opt/ibm/director/lwi/runtime/standby/eclipse/plugins..."
turn_off_error_chk
mkdir -p /opt/ibm/director/lwi/runtime/standby/eclipse/plugins
turn_on_error_chk

# copy standby plugin from itme dir to lwi/runtime/standby dir
echo "Copying ITME standby plugin to Director directory..."
cp -f  -r -P -f $pluginsDir/com.ibm.itme.standby_${standbyVersion} /opt/ibm/director/lwi/runtime/standby/eclipse/plugins

echo "Copying ITME utils plugin to lwi/runtime/standby dir"
cp -f  -r -P -f $pluginsDir/com.ibm.itme.utils_${utilsVersion} /opt/ibm/director/lwi/runtime/standby/eclipse/plugins


# create director standby dir
echo "creating opt/ibm/director/standby/bin directory"
turn_off_error_chk
mkdir -p  /opt/ibm/director/standby/bin  
turn_on_error_chk

# copy scripts from standby dir to director standby dir
echo "Copying ITME standby scripts to Director directory..."
cp -f  -r -P /opt/ibm/director/lwi/runtime/standby/eclipse/plugins/com.ibm.itme.standby_${standbyVersion}/scripts/*.sh /opt/ibm/director/standby/bin
chmod 755 /opt/ibm/director/standby/bin/*.sh 

# move one of the standby scripts to ha directory
echo "Move smfrmstandby.sh  to /opt/ibm/director/ha/plugins/tsa/m.6"
cp -P -f /opt/ibm/director/standby/bin/smfrmstandby.sh /opt/ibm/director/ha/plugins/tsa/m.6
# move dirc.properties file to vmi overwrite directory
echo "Move dirc.properties to /opt/ibm/director/vmi/data/overwrite/"
mv /opt/ibm/director/lwi/runtime/standby/eclipse/plugins/com.ibm.itme.standby_${standbyVersion}/dirc.properties /opt/ibm/director/vmi/data/overwrite
# delete standby plugin from itme dir
echo "Deleting ITME standby plugin from ITME directory..."
turn_off_error_chk
rm -r $pluginsDir/com.ibm.itme.standby*
turn_on_error_chk

#copy lap and setupwizard plugins to right location
cp -f -r -P $pluginsDir/com.ibm.itme.setupwizard.pages_${setupwizardVersion} /opt/ibm/director/lwi/runtime/SetupWizard/eclipse/plugins
cp -f -r -P $pluginsDir/com.ibm.itme.lap_${lapVersion} /opt/ibm/director/lwi/runtime/lap/eclipse/plugins
turn_off_error_chk
rm -rf $pluginsDir/com.ibm.itme.setupwizard.pages_${setupwizardVersion} 
rm -rf $pluginsDir/com.ibm.itme.lap_${lapVersion}
turn_on_error_chk

# update the dhcp config to ensure only 1 client is started
sed -i 's/DHCLIENT_BIN=""/DHCLIENT_BIN="dhclient"/' /etc/sysconfig/network/dhcp

# copy services.miscmgmt plugin from itme dir to ApplianceMgmt dir
echo "Copying ITME services.miscmgmt plugin to Director directory..."
cp -f -r -P $pluginsDir/com.ibm.itme.services.miscmgmt.nl1_${servicesMiscmgmtVersion_nl1} /opt/ibm/director/lwi/runtime/ApplianceMgmt/eclipse/plugins

#copy services.miscmgmt itme_firewall.xml from itme dir to vmi data directory.
#echo "Copying ITME services.miscmgmt itme_firewall.xml to Director directory..."
#removed and place into fsm_native_update_1.2.0
#cp -f -P $pluginsDir/com.ibm.itme.services.miscmgmt.nl1_${servicesMiscmgmtVersion_nl1}/itme_firewall.xml /opt/ibm/director/vmi/data/conf/appends/firewall 

# delete services.miscmgmt plugin from itme dir
echo "Deleting ITME services.miscmgmt plugin from ITME directory..."
rm -r $pluginsDir/com.ibm.itme.services.miscmgmt.nl1*

# copy usermanagement scripts for restricted shell commands 
echo "Copying scripts to /opt/ibm/director/vmi/scripts/execWithPrivilege"
vmiScripts=/opt/ibm/director/vmi/scripts/execWithPrivilege
cp -f  $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/chLocalPassword $vmiScripts
chmod 500 $vmiScripts/chLocalPassword
cp -f  $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/resetFSMToLocal $vmiScripts
chmod 500 $vmiScripts/resetFSMToLocal
cp -f  $pluginsDir/com.ibm.itme.utils_${utilsVersion}/enableLdapWatchdog.sh $vmiScripts
chmod 500 $vmiScripts/enableLdapWatchdog.sh
cp -f  $pluginsDir/com.ibm.itme.utils_${utilsVersion}/disableLdapWatchdog.sh $vmiScripts
chmod 500 $vmiScripts/disableLdapWatchdog.sh
echo "Copying restricted shell commands to /usr/smrshbin"
restrictedDir=/usr/smrshbin
cp -f  $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/chlocalpwd $restrictedDir
chmod 555 $restrictedDir/chlocalpwd
cp -f  $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/resetToLocal $restrictedDir
chmod 555 $restrictedDir/resetToLocal
cp -f  $pluginsDir/com.ibm.itme.utils_${utilsVersion}/enableLdapWatchdog $restrictedDir
chmod 555 $restrictedDir/enableLdapWatchdog
cp -f  $pluginsDir/com.ibm.itme.utils_${utilsVersion}/disableLdapWatchdog $restrictedDir
chmod 555 $restrictedDir/disableLdapWatchdog
cp -f  $pluginsDir/com.ibm.itme.utils_${utilsVersion}/createLdapWatchdog.sh /opt/ibm/director/vmi/bin
chmod 555 /opt/ibm/director/vmi/bin/createLdapWatchdog.sh
echo "copy com.ibm.itme.utils_${utilsVersion}/templates/* from itme dir to /opt/ibm/director/proddata/configmgr/predefined. "
cp -f  -r $pluginsDir/com.ibm.itme.utils_${utilsVersion}/templates/* /opt/ibm/director/proddata/configmgr/predefined
chmod 666 /opt/ibm/director/proddata/configmgr/predefined/*


# copy usermanagement appliance xml to /opt/ibm/director/lwi/conf/overrides/
echo "Copying com.ibm.itme.usermgmt/configFiles/MetaData_FSM.xml to /opt/ibm/director/lwi/conf/overrides"
cp -f $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/MetaData_FSM.xml /opt/ibm/director/lwi/conf/overrides/MetaData_FSM.xml

#Function appendRoles is used to append predefined roles and groups to director configuration files
#If the SMDefault role is already in the file, this step is skipped.
function appendRoles()
{
directorRolesFile=$1
userMgmtRolesFile=$2
tag=$3
num=`grep -c 'SMDefault' $directorRolesFile`
if [ "$num" = "0" ] 
then
	echo "Updating FSM  roles in $directorRolesFile"
	echo "Appending file[$userMgmtRolesFile]"
    sed -i s:$tag:' ':g $directorRolesFile
	cat $userMgmtRolesFile >> $directorRolesFile
	echo "$tag" >> $directorRolesFile
fi
}

### Copy usermgmt file for FRM roles to proddata and data directories ###
directorDir=/opt/ibm/director/proddata/defaults
userMgmtDir=/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.usermgmt_${usermgmtVersion}
echo "Copy $userMgmtDir/ibm-sys-roles-fsm.xml to $directorDir"
cp -P $userMgmtDir/ibm-sys-roles-fsm.xml $directorDir
appendRoles $directorDir/ibm-user-groups.xml $userMgmtDir/FrmUserGroups "</ibm-def-groups>"

#Change ibm-def-groups updated="false" to "true" ibm-user-groups.xml
sed -i 's/ibm-def-groups updated="false"/ibm-def-groups updated="true"/' $directorDir/ibm-user-groups.xml

directorDir=/opt/ibm/director/data
echo "Copy $userMgmtDir/ibm-sys-roles-fsm.xml to $directorDir"
cp -P $userMgmtDir/ibm-sys-roles-fsm.xml $directorDir

appendRoles $directorDir/ibm-user-groups.xml $userMgmtDir/FrmUserGroups "</ibm-def-groups>"

# Change ibm-def-groups updated="false" to "true" in ibm-user-groups.xml
sed -i 's/ibm-def-groups updated="false"/ibm-def-groups updated="true"/' $directorDir/ibm-user-groups.xml
### End - Copy usermgmt file for FRM roles to proddata and data directories ###

# copy security script to /opt/ibm/vmi/customize/chnetcfg.d/parms
mkdir -p /opt/ibm/vmi/customize/chnetcfg.d/parms
echo "Copying com.ibm.itme.security/scripts/chnetcfgFSMcheck.sh to /opt/ibm/vmi/customize/chnetcfg.d/parms"
cp -f  $pluginsDir/com.ibm.itme.security_${securityVersion}/chnetcfgFSMcheck.sh /opt/ibm/vmi/customize/chnetcfg.d/parms
chmod 500 /opt/ibm/vmi/customize/chnetcfg.d/parms/chnetcfgFSMcheck.sh

# copy date/time script to /opt/ibm/vmi/customize/chconfig.d/post
mkdir -p /opt/ibm/vmi/customize/chconfig.d/post
echo "Copying com.ibm.itme.utils/scripts/chconfigDateTimeLogEvent.sh to /opt/ibm/vmi/customize/chconfig.d/post"
cp -f  $pluginsDir/com.ibm.itme.utils_${utilsVersion}/chconfigDateTimeLogEvent.sh /opt/ibm/vmi/customize/chconfig.d/post
chmod 500 /opt/ibm/vmi/customize/chconfig.d/post/chconfigDateTimeLogEvent.sh


echo "***** Copying public key to /usr/local/signtool/keys/production *****"
turn_off_error_chk
mkdir -p /usr/local/signtool/keys/production  
turn_on_error_chk
prodKeys=/usr/local/signtool/keys/production   
cp -f *.pub $prodKeys  
chmod 400 $prodKeys/ibmfsm.pub  

echo "***** Copying public key to /usr/local/signtool/keys/development *****"
turn_off_error_chk
mkdir -p /usr/local/signtool/keys/development  
turn_on_error_chk
prodKeys=/usr/local/signtool/keys/development  
cp -f *.pub $prodKeys  
chmod 400 $prodKeys/ibmfsm.pub  

echo "Removing /opt/ibm/director/lwi/conf/overrides/sdmc.properties "
turn_off_error_chk
rm /opt/ibm/director/lwi/conf/overrides/sdmc.properties
turn_on_error_chk

# If flexcat properties already exist, then we don't want to override them
# as they may contain user modifications.

flexcatProperties=/opt/ibm/director/lwi/conf/overrides/FlexCat.properties
if [ ! -e "$flexcatProperties" ]; then
    echo "installFSMUpdate.sh : moving FlexCat.properties to overrides dir..."
    mv $pluginsDir/com.ibm.itme.flexcat_${flexcatVersion}/FlexCat.properties $flexcatProperties
    chmod 644 $flexcatProperties
else
	# Default value for FlexCat.sleep.before.os.discovery property was changed to 60 from 120.
	# So if this is an upgrade change the value to 60.
	sed -i 's/FlexCat.sleep.before.os.discovery\s*=\s*120/FlexCat.sleep.before.os.discovery=60/g' $flexcatProperties
	
	# Default value for FlexCat.allowed.max.os.imports property was changed to 5 from 2.
	# So if this is an upgrade change the value to 5.
	sed -i 's/FlexCat.allowed.max.os.imports\s*=\s*2/FlexCat.allowed.max.os.imports=5/g' $flexcatProperties
fi

# move flexcat-rg to HA controlled directory
# hacontrolled=/opt/ibm/director/ha/plugins/tsa/controlled
# echo "installFSMUpdate.sh : moving flexcat-rg to $hacontrolled directory"
# rm -f $hacontrolled/flexcat-rg
# mv $pluginsDir/com.ibm.itme.flexcat_${flexcatVersion}/flexcat-rg $hacontrolled/.
# dos2unix $hacontrolled/flexcat-rg
# chmod 500 $hacontrolled/flexcat-rg

#move flexcat_monitor.sh to Flexcat Apps directory
# flexcatapps=/opt/ibm/director/itme/apps/flexcat
# echo "installFSMUpdate.sh : moving flexcat_monitor.sh to $flexcatapps directory"
# mkdir -p $flexcatapps
# chmod 755 $itmeapps
# rm -f $flexcatapps/flexcat_monitor.sh
# mv $pluginsDir/com.ibm.itme.flexcat_${flexcatVersion}/flexcat_monitor.sh $flexcatapps/.
# dos2unix $flexcatapps/flexcat_monitor.sh
# chmod 500 $flexcatapps/flexcat_monitor.sh

# If fuelgauge properties already exist, then we don't want to override them
# as they may contain user modifications.
# Removed 11/12/2012.   This will be shipped in April 2013.  mjd.
# Uncommented on 2/5/2013 to fix the defect "Fuelgauge doesn't work after FSM is updated from GA3 to GA4".

fuelGaugeProperties=/opt/ibm/director/lwi/conf/overrides/Fuelgauge.properties
if [ ! -e "$fuelGaugeProperties" ]; then
    echo "installFSMUpdate.sh : moving Fuelgauge.properties to overrides dir..."
    mv $pluginsDir/com.ibm.itme.fuelgauge_${fuelgaugeVersion}/Fuelgauge.properties $fuelGaugeProperties
    chmod 644 $fuelGaugeProperties
fi

chmod 755 $itmeproddataDir/customizeVMI4FRM.sh
$itmeproddataDir/customizeVMI4FRM.sh

echo "Create TFTP Directory"
turn_off_error_chk
mkdir -p /tftpboot
turn_on_error_chk
chmod 755 /tftpboot

echo "Move .datamgmt.properties and .datamgmt.automanage.xml to /opt/ibm/director/lwi/conf/overrides"
overridesDir=/opt/ibm/director/lwi/conf/overrides
turn_off_error_chk
rm $overridesDir/.datamgmt.properties
turn_on_error_chk
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/.datamgmt.properties $overridesDir
turn_off_error_chk
rm $overridesDir/.datamgmt.automanage.xml
turn_on_error_chk
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/.datamgmt.automanage.xml $overridesDir


################################################################################
# Any files which have been placed in com.ibm.itme.build/appliance/non_plugin_data will
# automatically be picked up by the update build process.  If files need to be included
# from other locations in RTC, the FSM update team will need to be notified so
# that the build can be modifed to pick up the files.
echo "***** Move the non_plugin_data to itme dir. *****"
#defect defect XB130991
turn_off_error_chk
mkdir -p $itmeDir/non_plugin_data
rm -r  $itmeDir/non_plugin_data
turn_on_error_chk
mv $itmeproddataDir/non_plugin_data $itmeDir  

echo "moving addremoveulaip.sh to $itmeDir/"
mv $pluginsDir/com.ibm.itme.utils_${utilsVersion}/addremoveulaip.sh $itmeDir/
dos2unix $itmeDir/addremoveulaip.sh
chmod 544 $itmeDir/addremoveulaip.sh
mv $pluginsDir/com.ibm.itme.utils_${utilsVersion}/enabl*Function.sh $itmeDir/
mv $pluginsDir/com.ibm.itme.utils_${utilsVersion}/disabl*Function.sh $itmeDir/
chmod 544 $itmeDir/enabl*Function.sh
chmod 544 $itmeDir/disabl*Function.sh

#enable new function for 1.2.0
$itmeDir/enableLEDFunction.sh
$itmeDir/enableCentralizedManagementFunction.sh
$itmeDir/enableIOMConfigFunction.sh
$itmeDir/enableCMMConfigFunction.sh
$itmeDir/enableIMMConfigFunction.sh
$itmeDir/disableAEMFunction.sh
#since HA could be either disabled (Base FSM) or enabled (Troy install) we need to check its previous state to see if we need to turn it back off or leave it on
if [ -n "$(cat /opt/ibm/director/lwi/runtime/itme/DescopedFunction.properties | grep 'HA=false')" ]; then
	$itmeDir/disableHAFunction.sh
fi



# Move scripts from datamgmt and audit to bin directory.
echo "***** Move scripts from datamgmt and audit to bin directory. *****"

echo "Move .datamgmt scripts to empty /opt/ibm/vmi/customize/backup.d/backup and restore dirs."
rm -r -f /opt/ibm/vmi/customize/backup.d/backup/pre/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/backup/post/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/backup/notify/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/backup/cleanup/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/backup/validate/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/restore/pre/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/restore/post/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/restore/notify/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/restore/cleanup/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/restore/validate/*_default_*
rm -r -f /opt/ibm/vmi/customize/backup.d/restore/reboot/*_default_*
turn_off_error_chk
mkdir $pluginsDir/bin/
turn_on_error_chk
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_preBackupLdapStop.sh $pluginsDir/bin 
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_postBackupLdapStart.sh $pluginsDir/bin 
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_notifyRestoreHACheck.sh $pluginsDir/bin 
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_preSetVG.sh $pluginsDir/bin 
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_cleanupResetVG.sh $pluginsDir/bin 
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_cleanupBackupLdapStart.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/30_fsm_validateBackupNoJobs.sh $pluginsDir/bin 
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/backupHDD.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/restoreHDD.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/deleteBackup.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/implementCron.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/launchBackup.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/launchRestore.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/listBackupsScript.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/mountUSB.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/listBackups.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/slpcheck.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/slpcheckBackend.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/doPF.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/deleteBackupCmd.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/genULA.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/dmAttachedULA.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/parseDMULA.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/manageFilesonHost.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.datamgmt_${datamgmtVersion}/manageFilesonHostCmd.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.audit_${auditVersion}/auditLogger.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.audit_${auditVersion}/lsalogs.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.audit_${auditVersion}/rmlog.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.utils_${utilsVersion}/RGFunctions.sh $pluginsDir/bin  
mv $pluginsDir/com.ibm.itme.utils_${utilsVersion}/installFSMUpdateLdap.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/managedChassisFound.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/centrallyManagedChassisFound.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/fixExpiredSSHpwd.sh $pluginsDir/bin
mv $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/getActiveSSHUsers.sh $pluginsDir/bin

chmod 755 $pluginsDir/bin/managedChassisFound.sh
chmod 755 $pluginsDir/bin/centrallyManagedChassisFound.sh
chmod 755 $pluginsDir/bin/fixExpiredSSHpwd.sh
chmod 755 $pluginsDir/bin/getActiveSSHUsers.sh

# Change permission to 711 for these two scripts
echo "***** Change permission to 711 for these two scripts *****"
chmod 711 $pluginsDir/bin/launchBackup.sh
chmod 711 $pluginsDir/bin/launchRestore.sh


# Update slpcheck.sh and make it runnable by USERID 
echo "***** Update slpcheck.sh and make it runnable by USERID *****"
dos2unix $pluginsDir/bin/slpcheck.sh
dos2unix $pluginsDir/bin/slpcheckBackend.sh
chmod 555 $pluginsDir/bin/slpcheck.sh
chmod 555 $pluginsDir/bin/slpcheckBackend.sh
cp -f $pluginsDir/bin/slpcheck.sh /usr/smrshbin/slpcheck.sh
cp -f $pluginsDir/bin/slpcheckBackend.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/slpcheckBackend.sh
chmod 555 /usr/smrshbin/slpcheck.sh
chmod 555 /opt/ibm/director/vmi/scripts/execWithPrivilege/slpcheckBackend.sh
chmod 755 /opt/ibm/director/proddata/itme/datamgmt/scripts/backupHDD.sh
chmod 755 /opt/ibm/director/proddata/itme/datamgmt/scripts/restoreHDD.sh
chmod 755 /opt/ibm/director/proddata/itme/datamgmt/scripts/deleteBackupCmd.sh
chmod 755 /opt/ibm/director/proddata/itme/datamgmt/scripts/listBackups.sh

# Update symbolic links.  Need the -f parameter to force a relink if one already exists.
ln -f -s $pluginsDir/bin/30_fsm_preBackupLdapStop.sh /opt/ibm/vmi/customize/backup.d/backup/pre/30_fsm_preBackupLdapStop
ln -f -s $pluginsDir/bin/30_fsm_postBackupLdapStart.sh /opt/ibm/vmi/customize/backup.d/backup/post/30_fsm_postBackupLdapStart
ln -f -s $pluginsDir/bin/30_fsm_notifyRestoreHACheck.sh /opt/ibm/vmi/customize/backup.d/restore/notify/30_fsm_notifyRestoreHACheck.sh
ln -f -s /opt/ibm/vmi/customize/backup.d/builtin/20_quiesceDirector_backupPre /opt/ibm/vmi/customize/backup.d/backup/pre/20_quiesceDirector_backupPre
ln -f -s /opt/ibm/vmi/customize/backup.d/builtin/20_quiesceDirector_backupPost /opt/ibm/vmi/customize/backup.d/backup/post/20_quiesceDirector_backupPost
ln -f -s $pluginsDir/bin/30_fsm_preSetVG.sh /opt/ibm/vmi/customize/backup.d/backup/pre/30_fsm_prebackupSetVG.sh
ln -f -s $pluginsDir/bin/30_fsm_preSetVG.sh /opt/ibm/vmi/customize/backup.d/restore/pre/30_fsm_prerestoreSetVG.sh
ln -f -s $pluginsDir/bin/30_fsm_cleanupResetVG.sh /opt/ibm/vmi/customize/backup.d/backup/cleanup/30_fsm_cleanupbackupResetVG.sh
ln -f -s $pluginsDir/bin/30_fsm_cleanupResetVG.sh /opt/ibm/vmi/customize/backup.d/restore/reboot/30_fsm_rebootrestoreResetVG.sh
ln -f -s $pluginsDir/bin/30_fsm_cleanupBackupLdapStart.sh /opt/ibm/vmi/customize/backup.d/backup/cleanup/30_fsm_cleanupBackupLdapStart.sh
ln -f -s $pluginsDir/bin/30_fsm_validateBackupNoJobs.sh /opt/ibm/vmi/customize/backup.d/backup/validate/30_fsm_validateBackupNoJobs.sh
ln -f -s /opt/ibm/director/proddata/itme/datamgmt/scripts/backupHDD.sh /usr/smrshbin/backupHDD
ln -f -s /opt/ibm/director/proddata/itme/datamgmt/scripts/restoreHDD.sh /usr/smrshbin/restoreHDD
ln -f -s $pluginsDir/bin/launchBackup.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/launchBackup.sh
ln -f -s $pluginsDir/bin/launchRestore.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/launchRestore.sh
ln -f -s $pluginsDir/bin/listBackupsScript.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/listBackupsScript.sh
ln -f -s $pluginsDir/bin/deleteBackup.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/deleteBackup.sh
ln -s $pluginsDir/bin/manageFilesonHost.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/manageFilesonHost.sh
ln -f -s /opt/ibm/director/proddata/itme/datamgmt/scripts/listBackups.sh /usr/smrshbin/listBackups
ln -f -s $pluginsDir/bin/auditLogger.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/auditLogger
ln -f -s /opt/ibm/director/proddata/itme/datamgmt/scripts/deleteBackupCmd.sh /usr/smrshbin/deleteBackup

echo "***** Copying included license keys into place *****"
directorKeysDir=/opt/ibm/director/keys
mv $pluginsDir/com.ibm.itme.licensemgmt_${licensemgmtVersion}/*.lic $directorKeysDir




#call the 00_baseFRMCustom script in postinst.d.  normally this gets called on a reboot, but since 
#this installFSMupdate.sh is running on a reboot, we will avoid having to reboot yet again.
chmod 755 /opt/ibm/vmi/customize/postinst.d/00_baseFRMCustom
/opt/ibm/vmi/customize/postinst.d/00_baseFRMCustom

# copy the oem-disabled.xml file to disable existing tasks in director/CSDA/etc.	
	FRMoemFile=$pluginsDir/com.ibm.itme.common_${commonVersion}/oem-disabled.xml
	mv $FRMoemFile /opt/ibm/director/proddata/

# Update Welcome page properties file so correct setup steps display
#=====================================================================
echo "***** Update Welcome page properties file so correct setup steps display *****"

welcomeFile=/opt/ibm/director/lwi/conf/overrides/USMiZWelcome_FSM.properties

appendLine1="com.ibm.itme.console.welcome.step.DomainManagementExt.StepOrder=150"
newStep1="com.ibm.itme.console.welcome.step.ConfigureChassisComponentsExt.StepOrder=350"
newStep2="com.ibm.itme.console.welcome.step.FlexcatOsDeployExt.StepOrder=450"
newStep3="com.ibm.itme.console.welcome.step.UpdateChassisComponentsExt.StepOrder=550"
newStep4="com.ibm.itme.console.welcome.step.FlexExplorerExt.StepOrder=650"


# Add the new Welcome steps for the initial setup page
sed -i "/$appendLine1/ a  $newStep1" $welcomeFile  
sed -i "/$newStep1/ a  $newStep2" $welcomeFile  
sed -i "/$newStep2/ a  $newStep3" $welcomeFile
sed -i "/$newStep3/ a  $newStep4" $welcomeFile  


# Remove the old steps by setting stepOrder to 0 
sed -i -e 's/\(com.ibm.itme.console.welcome.step.UpdateTheCMMExt.StepOrder\)=[0-9]\+/\1=0/' $welcomeFile 
sed -i -e 's/\(com.ibm.itme.console.welcome.step.OperatingSystemsDiscoveryExt.StepOrder\)=[0-9]\+/\1=0/' $welcomeFile 
sed -i -e 's/\(com.ibm.itme.console.welcome.step.UpdateIOModulesExt.StepOrder\)=[0-9]\+/\1=0/' $welcomeFile 
sed -i -e 's/\(com.ibm.itme.console.welcome.step.ChassisManagerExt.StepOrder\)=[0-9]\+/\1=0/' $welcomeFile 

#========================================================================
# End: Update Welcome page properties file so correct setup steps display
#=========================================================================
# Update the cimcli wrapper script
echo "***** Update the cimcli wrapper script *****"
scriptsFolder=/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.setupwizard.pages_${setupwizardPagesVersion}
cp -f -P $scriptsFolder/cimcli.sh /usr/smrshbin/cimcli
cp -f -P $scriptsFolder/cimcli2.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/cimcli
# Update the quicklogs script
echo "***** Update the quicklogs script *****"
cp -f -P $scriptsFolder/quicklogs.sh /usr/smrshbin/quicklogs
cp -f -P $scriptsFolder/quicklogs2.sh /opt/ibm/director/vmi/scripts/execWithPrivilege/quicklogs
chmod 555 /opt/ibm/director/vmi/scripts/execWithPrivilege/quicklogs
chmod 555 /usr/smrshbin/quicklogs
chmod 555 /opt/ibm/director/vmi/scripts/execWithPrivilege/cimcli
chmod 555 /usr/smrshbin/cimcli
# Removing slpRegs.sh as its no longer in use.
rm /opt/ibm/director/vmi/bin/slpRegs.sh

#script to verify FSM version for translation.	
cp -P $scriptsFolder/chconfigFSMcheck.sh /opt/ibm/vmi/customize/chconfig.d/pre
chmod 555 /opt/ibm/vmi/customize/chconfig.d/pre/chconfigFSMcheck.sh


# GA3 will be English Only, but NLS artifacts are shipped so need to make sure only English is displayed
# Checking with Alex  9/26/2012
# ->  This patch IS NOT needed in the update package.  In a future relase when NLS is enabled and
# supported in the FSM, a new patch is needed to undo the patch below.  The patch below
# was shipped in the GA1 mfg_preload image and was never needed in any update package.  I am
# leaving this comment here so that this item is not lost for the next release!!
# ##################################
cp -P nolangpatch.jar.patch   /opt/ibm/director/lwi/runtime/core/eclipse/plugins/com.ibm.pvc.webcontainer_6.2.3.20130212-0830/nolangpatch.jar
sed -i 's/Bundle-ClassPath: webcontainer.jar/Bundle-ClassPath: .\/nolangpatch.jar,webcontainer.jar/'  /opt/ibm/director/lwi/runtime/core/eclipse/plugins/com.ibm.pvc.webcontainer_6.2.3.20130212-0830/META-INF/MANIFEST.MF 


echo "installFSMUpdate.sh : Set vmi_settings.properties to indicate signed updates"
#appliancePropertiesDestination=/opt/ibm/director/vmi/data/overwrite/vmi_setting.properties
#sed -i 's/um.secureCheck=false/um.secureCheck=true/g' $appliancePropertiesDestination
# copy the appliance override properties file 
cp -f vmi_setting.properties /opt/ibm/director/vmi/data/overwrite/vmi_setting.properties


cp -f -r -P $pluginsDir/com.ibm.itme.utils_${utilsVersion} /opt/ibm/director/lwi/runtime/lap/eclipse/plugins
cp -f -r -P $pluginsDir/com.ibm.itme.utils.nl1_${utilsVersion} /opt/ibm/director/lwi/runtime/lap/eclipse/plugins

# copy services.miscmgmt itme_firewall.xml from itme dir to vmi data directory.
#Kyle Henderson to Yi YZ Zhao/China/IBM@IBMCN, Long Quan Sha/China/IBM@IBMCN, Jian Peng Guo/China/IBM@IBMCN
#Flexcat is adding firewall rules for FSM FP3.  Of course, their new firewall append xml file works fine for new installations but they need it to also work for existing installed systems.  I recall we had a similar issue in SDMC GA1 where they forgot to open a port or two.  I think that solution was that they had to add the rules to the internal files because the xml is only references during initial setup.  From then on the internal files are use to keep track of the current settings of the applications.  Is my memory correct?  Are there any utility scripts that can be called to update these files and iptables?
#
#The files I'm thinking that need updating are:
#./data/networksetting/firewall/eth1-FIREWALL-SETTING
#./data/networksetting/firewall/eth0-FIREWALL-SETTING
#
echo "Copying ITME services.miscmgmt itme_firewall.xml to Director directory..."
cp -f -P $pluginsDir/com.ibm.itme.services.miscmgmt.nl1_${servicesMiscmgmtVersion_nl1}/itme_firewall.xml /opt/ibm/director/vmi/data/conf/appends/firewall 

#=====================================================================

#=========================================================================
# Check if unsecure SNMPv1 and v2 need to be added.
#=========================================================================
FILE=/opt/ibm/director/lwi/conf/overrides/frm.properties
CAPTURE=
CAPTURE=$(grep -i 'security_policy_level' $FILE  | cut -f2 -d'=')
echo "Security mode:" $CAPTURE >> $LOGFILE
if [ $CAPTURE == 20 ];
then
snmpv1=
snmpv1=$(sed -n '/snmp.trap.v1.enabled/p' /opt/ibm/director/data/snmp/SNMPServer.properties)
snmpv2=
snmpv2=$(sed -n '/snmp.trap.v2.enabled/p' /opt/ibm/director/data/snmp/SNMPServer.properties)
echo "snmp found:" $snmpv1 " " $snmpv2 >> $LOGFILE
if [ "$snmpv1" == ""  ];
then
echo "snmp.trap.v1.enabled=false" >> /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Added snmpv1 false to file." >> $LOGFILE
else
sed -i 's/snmp.trap.v1.enabled=true/snmp.trap.v1.enabled=false/' /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Changed snmpv1 value to false " >> $LOGFILE 
fi
if [ "$snmpv2" == ""  ];
then
echo "snmp.trap.v2.enabled=false" >> /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Added snmpv2 false to file." >> $LOGFILE
else
sed -i 's/snmp.trap.v2.enabled=true/snmp.trap.v2.enabled=false/' /opt/ibm/director/data/snmp/SNMPServer.properties
echo "Changed snmpv2 value to false " >> $LOGFILE 
fi
else
echo "In legacy mode - file OK " >> $LOGFILE
sed -i 's/snmp.trap.v1.enabled=false/snmp.trap.v1.enabled=true/' /opt/ibm/director/data/snmp/SNMPServer.properties
sed -i 's/snmp.trap.v2.enabled=false/snmp.trap.v2.enabled=true/' /opt/ibm/director/data/snmp/SNMPServer.properties
fi


# Remove Console javascripts from FSM stack
	echo "Start - Remove Console javascripts from FSM stack"
turn_off_error_chk
		rm -r $pluginsDir/com.ibm.itme.console_*/scripts/ChassisMap
		rm -r $pluginsDir/com.ibm.itme.console_*/scripts/nls
		rm -r $pluginsDir/com.ibm.itme.console_*/scripts/dojo/ibm
		rm -r $pluginsDir/com.ibm.itme.console_*/scripts/dojo/itme
		rm $pluginsDir/com.ibm.itme.console_*/scripts/dojo/dojo/dojo.js.uncompressed.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/finder/ContextTaskDataStore.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/finder/Finder.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/finder/FinderBaseDataStore.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/finder/ResourceDataStore.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/finder/TaskCategory.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/finder/TaskDataStore.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/ChassisMapMRI.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/CommonActionsMenu.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/DojoMenuOverride.js
		rm $pluginsDir/com.ibm.itme.console_*/scripts/dojoRequires.js
turn_on_error_chk
	echo "End   - Remove Console javascripts from FSM stack"
	
# add usermanagement scripts to the role_permission.xml file.  
# This is needed in order for smadmin to run /usr/smrshbin/enableLdapWatchdog,etc
sed -i 's/\(\s*\)<name>smadmin<\/name>/&\n\1<permission id="resetToLocal"\/>\n\1<permission id="chlocalpwd"\/>\n\1<permission id="enablePEonFSM"\/>\n\1<permission id="enableLdapWatchdog"\/>\n\1<permission id="disableLdapWatchdog"\/>\n\1<permission id="slpcheckBackend.sh"\/>\n\1<permission id="foundationsFinishSetup"\/>/' /opt/ibm/director/vmi/data/conf/role_permission.xml
# check if HA is running before enabling ldap watchdog 
/opt/ibm/director/vmi/scripts/execWithPrivilege/smhapstatus.sh  &>/dev/null
HArc=$? 
echo "  HA return code getting HA status is $HArc"  
if [ $HArc -eq 4 ]; then
  echo "  HA is not configured. Run enableLdapWatchdog"
  /usr/smrshbin/enableLdapWatchdog
else
  echo "  HA is configured so do NOT run enableLdapWatchdog. "
fi
echo "End of enableLdapWatchdog"

#Update Director auditing with FSM category. DPSM also updates this file so we could have a race condition
#  We are adding SDMC and Config Patterns here because I believe the Director update removes them and the respective teams don't
#  add them back in themselves.
cpAudit=`sed '/^\#/d' "/opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt" | grep 'IBMSystemsDirectorProgram.Audit.Configuration Patterns'  | tail -n 1`
if [ -z "$cpAudit" ]; then
  sed -i~ "\$aevent.filter.type.6=IBMSystemsDirectorProgram.Audit.Configuration Patterns" /opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt
  echo "Setting Configuration Patterns auditing: event.filter.type.6=IBMSystemsDirectorProgram.Audit.Configuration Patterns"
fi

sdmcAudit=`sed '/^\#/d' "/opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt" | grep 'IBMSystemsDirectorProgram.Audit.SDMC'  | tail -n 1`
if [ -z "$sdmcAudit" ]; then
  sed -i~ 's/event.filter.type.4=IBMSystemsDirectorProgram.Audit.SDMC//g; ' /opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt
  sed -i~ "\$aevent.filter.type.7=IBMSystemsDirectorProgram.Audit.SDMC" /opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt
  echo "Setting SDMC auditing: event.filter.type.7=IBMSystemsDirectorProgram.Audit.SDMC"
fi

fsmAudit=`sed '/^\#/d' "/opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt" | grep 'IBMSystemsDirectorProgram.Audit.FSM'  | tail -n 1`
if [ -z "$fsmAudit" ]; then
  sed -i~ "\$aevent.filter.type.8=IBMSystemsDirectorProgram.Audit.FSM" /opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt
  echo "Setting FSM auditing: event.filter.type.8=IBMSystemsDirectorProgram.Audit.FSM"
fi

auditingDataDir=/opt/ibm/director/data
auditingPluginDir=/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/com.ibm.itme.audit_${auditVersion}
echo "Copy $auditingPluginDir/ibm-auditcat-actions-fsm.xml to $auditingDataDir"
cp -P $auditingPluginDir/ibm-auditcat-actions-fsm.xml $auditingDataDir
#TEMPORARY: copy file to temp because we think Director update is overwriting
cp /opt/ibm/director/classes/extensions/Audit.TWGSimpleEventFilterExt /tmp/Audit.TWGSimpleEventFilterExt

#Adding/increasing the perf.extended.discovery.timeout value to 120 is for
# defect XB132642. In a future release (2Q13?) Director or Storage Control will be
# making a fix and this should be able to be removed.
timeout=`sed '/^\#/d' "/opt/ibm/director/lwi/conf/overrides/USMIKernel.properties" | grep 'perf.extended.discovery.timeout'  | tail -n 1 | cut -d "=" -f2- | sed 's/^[[:space:]]*//;s/[[:space:]]*$//'`

if [ -z "$timeout" ]; then
  echo "perf.extended.discovery.timeout=120" >> /opt/ibm/director/lwi/conf/overrides/USMIKernel.properties
  echo "Setting perf.extended.discovery.timeout to 120"
elif [ $timeout -lt 120 ]; then
  sed -i 's/perf.extended.discovery.timeout=.*$/perf.extended.discovery.timeout=120/g' /opt/ibm/director/lwi/conf/overrides/USMIKernel.properties
  echo "Increasing perf.extended.discovery.timeout from $timeout to 120"
else
  echo "perf.extended.discovery.timeout is set to $timeout"
fi	
####====================START -- LDAP related changes===========================####

#===============================================
# Run script to change local user accounts with mangled passwords to never expire - XB144307
#===============================================
echo "change local user accounts with mangled password (!) to Never expire"
$pluginsDir/bin/fixExpiredSSHpwd.sh

#===============================================
# Add ldap to list of common services
#===============================================
# 2/2013 KKR Add new plugin to be used for ldap service

# copy services.ldap plugin from itme dir to ApplianceMgmt dir
echo "Copying ITME services.ldap plugin to Director directory..."
cp -r -P $pluginsDir/com.ibm.itme.services.ldap.nl1_${servicesLdapVersion_nl1} /opt/ibm/director/lwi/runtime/ApplianceMgmt/eclipse/plugins

echo "Copying fsm_service_mgmt.xml  to /opt/ibm/director/vmi/data/servicemgmt/appends directory" 
mkdir -p /opt/ibm/director/vmi/data/servicemgmt/appends
cp -P $pluginsDir/com.ibm.itme.services.ldap.nl1_${servicesLdapVersion_nl1}/fsm_service_mgmt.xml /opt/ibm/director/vmi/data/servicemgmt/appends/ 
#==================================================================================================
# Upgrade the LDAP server to V2 if necessary ...
#==================================================================================================
echo "***** Upgrade the LDAP server to V2 if necessary *****"
upgrade_ldap
#==================================================================================================
# End - Upgrade the LDAP server to V2 if necessary ...
#==================================================================================================
#==================================================================================================
# Add changes for PAM - Pluggable Authentication Modules - LDAP and usermgmt
#==================================================================================================
# This is done after the upgrade since ldap is started during the upgrade 

#move usrmgmt native C pwd code to proper location in FSM installed image
echo "***** move usrmgmt native C pwd code to proper location in FSM installed image *****"
pam_module=$pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/pam_fsm_password.so
echo "installFSMUpdate.sh : Check for pam_fsm_password.so"
if [ -e $pam_module ]; then
    echo "installFSMUpdate.sh : Moving new version pam_fsm_password.so to /lib64/security"
    mv -f $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/pam_fsm_password.so /lib64/security
    chmod 755 /lib64/security/pam_fsm_password.so
fi
pam_module2=$pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/pam_fsm_os_password.so
echo "installFSMUpdate.sh : Check for pam_fsm_os_password.so"
if [ -e $pam_module2 ]; then
    echo "installFSMUpdate.sh : Moving new version pam_fsm_os_password.so to /lib64/security"
    mv -f $pluginsDir/com.ibm.itme.usermgmt_${usermgmtVersion}/pam_fsm_os_password.so /lib64/security
    chmod 755 /lib64/security/pam_fsm_os_password.so
fi
echo "installFSMUpdate.sh : ***Updating files for PAM support***"




echo "installFSMUpdate.sh : ***Update ldap.conf***"

LDAP_FILE=/etc/openldap/ldap.conf
LDAP_BACKUP=/etc/openldap/ldap.conf.backup
USE_FILE=$LDAP_FILE
grep -q "pam_password exop" /etc/openldap/ldap.conf || echo "pam_password exop" >> $LDAP_FILE
grep -q "pam_password exop" /etc/openldap/ldap.conf || echo "pam_password exop" >> $LDAP_BACKUP

searchline=`grep "URI ldap://localhost:389" $LDAP_FILE`
if [ "${#searchline}" -eq  0 ];then
  USE_FILE=$LDAP_BACKUP
fi  

set -
bindpw=`grep "bindpw" $USE_FILE `
password=$(echo $bindpw | cut -f2 -d' ')
#echo "`cat /etc/openldap/ldap.conf `"
set -x

echo "installFSMUPdate.sh : LDAP status"
/etc/init.d/ldap status %
echo "installFSMUpdate.sh : Get password policy values"

# all output goes to the same file. ldap not running or ppolicy values
set -
ldapsearch -h localhost -D  cn=manager,dc=ibmbase,dc=com -w $password -b cn=default,ou=policies,dc=ibmbase,dc=com &>/tmp/ppolicy.file
set -x
FRMPROP=/opt/ibm/director/lwi/conf/overrides/frm.properties
FRMPROP_SHORT=frm.properties
MAXFAIL=`grep   pwdMaxFailure  /tmp/ppolicy.file | cut -f2 -d: | cut -f2 -d' '`
LOCKOUT=`grep  pwdLockoutDuration  /tmp/ppolicy.file | cut -f2 -d: | cut -f2 -d' '`
if [ "${#MAXFAIL}" -eq  0 ]; then
  echo "installFSMUPdate.sh : ldapsearch failed. LDAP error is `cat /tmp/ppolicy.file `"
  echo "installFSMUpdate.sh : Use $FRMPROP_SHORT file"
  MAX=`grep pwdMaxFailure $FRMPROP`
  MAXFAIL=`grep   pwdMaxFailure  $FRMPROP | cut -f2 -d= | cut -f2 -d' '`
  LOCKOUT=`grep  pwdLockoutDuration  $FRMPROP | cut -f2 -d= | cut -f2 -d' '`
  echo "installFSMUpdate.sh : pwdMaxFailure set to $MAXFAIL"
  echo "installFSMUpdate.sh : pwdLockoutDuration set to $LOCKOUT"
else
 MAXFAIL=`grep   pwdMaxFailure  /tmp/ppolicy.file | cut -f2 -d: | cut -f2 -d' '`
 LOCKOUT=`grep  pwdLockoutDuration /tmp/ppolicy.file | cut -f2 -d: | cut -f2 -d' '`
 echo "installFSMUpdate.sh : pwdMaxFailure set to $MAXFAIL"
 echo "installFSMUpdate.sh : pwdLockoutDuration set to $LOCKOUT"
fi
if [ "${#MAXFAIL}" -eq  0 ]; then
  echo "installFSMUpdate.sh : No value collected. Resetting MAXFAIL to 20"
  MAXFAIL=20
fi
if [ "${#LOCKOUT}" -eq  0 ]; then
 echo "installFSMUpdate.sh : No value collected. Resetting LOCKOUT to 3600"
  LOCKOUT=3600
fi

echo "installFSMUpdate.sh : ***Update common-auth***"
newline="auth required  pam_tally2.so onerr=fail deny=$MAXFAIL unlock_time=$LOCKOUT"

oldline=`grep pam_tally2.so /etc/pam.d/common-auth`
afterline=`grep pam_env.so /etc/pam.d/common-auth`
if [ "${#oldline}" -eq  0 ]; then
  sed -i "/$afterline/ a  $newline" /etc/pam.d/common-auth 
else 
  sed -i "s/$oldline/$newline/g"  /etc/pam.d/common-auth
fi

echo "installFSMUpdate.sh : ***Update common-password***"
# add pam_fsm_password.so after ...cracklib...
currentline=`grep pam_fsm_password.so /etc/pam.d/common-password`
if [ "${#currentline}" -eq  0 ]; then
 cracklibline=`grep pam_cracklib.so /etc/pam.d/common-password`
 fsmline="password  required    /lib64/security/pam_fsm_password.so"
 sed -i "/$cracklibline/ a  $fsmline"  /etc/pam.d/common-password 
 sed -i "s|\(^$cracklibline\)|#\1|" /etc/pam.d/common-password 
fi
 
# add pam_fsm_os_password.so after pam_ldap.so
pamldapline0=`grep pam_ldap.so /etc/pam.d/common-password`
currentline1=`grep pam_fsm_os_password.so /etc/pam.d/common-password`
 
if [ "${#currentline1}" -eq  0 ]; then
 fsmline1="password  required    /lib64/security/pam_fsm_os_password.so"

 pamldapline01=`grep pam_ldap.so /etc/pam.d/common-password` 
 sed -i "\,$pamldapline01, a $fsmline1" /etc/pam.d/common-password
fi
 
pamldapline2=$(echo "$pamldapline0" | sed 's/sufficient/ required/')
sed -i "s|$pamldapline0|$pamldapline2|"  /etc/pam.d/common-password
 
# comment out uncomented pam_unix_passwd - it has been replaced by pam_fsm_os_password.so
unixline=`grep pam_unix_passwd.so -m1 /etc/pam.d/common-password`
sed -i "s|\(^$unixline\)|#\1|" /etc/pam.d/common-password


echo "installFSMUpdate.sh : ***Update common-account***"
currentline=`grep pam_tally2.so /etc/pam.d/common-account`
if [ "${#currentline}" -eq  0 ]; then
  accountline="account required        pam_tally2.so"
  sed  -i "/pam_unix_acct.so/ i  $accountline"  /etc/pam.d/common-account 
fi

# delete files in /tmp
turn_off_error_chk
rm -f /tmp/ppolicy.file
turn_on_error_chk

# ***** end of updates for PAM ****
#==================================================================================================
# End --- Updates for PAM - Pluggable Authentication Modules - usermgmt
#==================================================================================================
####====================END -- LDAP related changes===========================####

echo "***** End of installFSMUpdate.sh *****"


