#
# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# (C) Copyright IBM Corp. 2012 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#

#!/bin/bash

binDir=/opt/ibm/director/lwi/runtime/itme/eclipse/plugins/bin
PARSE_DM_ULA=$binDir/parseDMULA.sh
DM_ULA_LOG=/var/log/dmULA.log
FRM_PROP=/opt/ibm/director/lwi/conf/overrides/frm.properties

#======== MAIN ========
#Current ifconfig
echo $(date) >> $DM_ULA_LOG 2>&1
echo "=====eth0 (before)=====" >> $DM_ULA_LOG 2>&1
echo "`ifconfig eth0`" >> $DM_ULA_LOG 2>&1

# 0 HA is active
# 3 HA is passive
# 4 HA is not configured
# 8 HA node is pending 
# Run get HA status
/opt/ibm/director/vmi/scripts/execWithPrivilege/smhapstatus.sh  &>/dev/null
HArc=$?
if [ $HArc -ne 4 ]; then
	echo "HA is configured. Exiting script." >> $DM_ULA_LOG 2>&1
	exit 0
fi

#Calling script to get DMULA
DMULA="$($PARSE_DM_ULA)"
echo "Reading DM ULA IP from frm.properties $DMULA" >> $DM_ULA_LOG 2>&1

#If DMULA is not null
if [ -n "$DMULA" ]; then
	#Check if FSM still have DM ULA assigned. If not, reassign.
	#Get current list of ip for eth0, format is x:x:x:x:x:x:x:x/64
	declare -a old_addresses=$(ip addr show eth0 | grep -w "inet6" | grep -w "global" | sed -e "s/^[[:space:]]*//" | cut -d' ' -f2)
	#Iterate over current list of ip and determine if DM ula ip exist
	for every_address in $old_addresses; do
		if [ "$DMULA" == "$every_address" ]; then
			echo "Found DM ula ip $every_address" >> $DM_ULA_LOG 2>&1
			exit 0
		fi
	done
	#attach DM ULAIP6 to eth0
    /opt/ibm/director/lwi/runtime/itme/addremoveulaip.sh eth0 $DMULA "add"
	
	#echo changed ifconfig
    echo "=====eth0 (after)=====" >> $DM_ULA_LOG 2>&1
    echo "`ifconfig eth0`" >> $DM_ULA_LOG 2>&1
else 
	#Generate a dm ula ip
    ULA=`$binDir/genULA.sh`
    SUFFIX=$(ip -6 addr show dev eth0 | grep "inet6 fe80" | awk '{print $2}' | sed -e s/fe80::// -e s/\\/64//)		   
    DMULAIP6=${ULA%/*}${SUFFIX}/64
    DMULAIP6=`echo $DMULAIP6 | sed -e "s/::/:0:/g"`
    echo "Newly generated dmULA=$DMULAIP6" >> $DM_ULA_LOG 2>&1
  
    #attach DM ULAIP6 to eth0
    /opt/ibm/director/lwi/runtime/itme/addremoveulaip.sh eth0 $DMULAIP6 "add"
 
    #Add new IP to frm.properties with \: format
	DMULAIP6=`echo $DMULAIP6 | sed -e "s/\:/\\\\\:/g"`
    echo "DM_ULA_ETH0=$DMULAIP6" >> $FRM_PROP 2>&1
   
    #echo changed ifconfig
    echo "=====eth0 (after)=====" >> $DM_ULA_LOG 2>&1
    echo "`ifconfig eth0`" >> $DM_ULA_LOG 2>&1
fi
